Features
========

invenio-sword supports the following:

* Deposit of metadata, individual files and packages
* Support for In-Progress deposits

See `the reference implementation status page
<https://github.com/swordapp/swordv3/wiki/Python-Reference-Implementation-Support>`_ for further details on
implementation progress.
